<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="pl">
<defaultcodec></defaultcodec>
<context>
    <name>@default</name>
    <message>
        <source>Web browser was not specified. Visit the configuration section</source>
        <translation>Przeglądarka WWW nie została określona. Wybierz przeglądarkę WWW w oknie konfiguracji</translation>
    </message>
    <message>
        <source>Could not spawn Web browser process. Check if the Web browser is functional</source>
        <translation>Nie można uruchomić przeglądarki. Sprawdź czy Twoja przeglądarka działa poprawnie</translation>
    </message>
    <message>
        <source>English</source>
        <translation>Angielski</translation>
    </message>
    <message>
        <source>Italian</source>
        <translation>Włoski</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation>Polski</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Niemiecki</translation>
    </message>
    <message>
        <source>Force running Kadu (not recommended).</source>
        <translation>Uruchom mimo to (nie zalecane).</translation>
    </message>
    <message>
        <source>Quit.</source>
        <translation>Porzuć.</translation>
    </message>
    <message>
        <source>Please do not run Kadu as a root!
It&apos;s a high security risk!</source>
        <translation>Proszę nie uruchamiać Kadu jako root!
Jest to wysoce ryzykowne!</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Francuski</translation>
    </message>
    <message>
        <source>Another Kadu is running on this profile but I cannot get its process ID.</source>
        <translation>Inne Kadu działa już na tym profilu, ale nie udało się znaleźć identyfikatora jego procesu.</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <source>Mark</source>
        <translation></translation>
    </message>
    <message>
        <source>Smith</source>
        <translation></translation>
    </message>
    <message>
        <source>Jimbo</source>
        <translation></translation>
    </message>
    <message>
        <source>Yesterday at </source>
        <translation>Wczoraj o </translation>
    </message>
    <message>
        <source>dddd at </source>
        <translation>dddd o </translation>
    </message>
    <message>
        <source>%1 weeks ago at </source>
        <translation>%1 tygodnie temu o </translation>
    </message>
    <message>
        <source>%1 weeks and day ago at </source>
        <translation>%1 tygodnie i jeden dzień temu o </translation>
    </message>
    <message>
        <source>%1 weeks and %2 days ago at </source>
        <translation>%1 tygodnie %2 dni temu o </translation>
    </message>
    <message>
        <source>week ago at </source>
        <translation>Tydzień temu o </translation>
    </message>
    <message>
        <source>week and day ago at </source>
        <translation>Tydzień i jeden dzień temu o </translation>
    </message>
    <message>
        <source>week and %2 days ago at </source>
        <translation>Tydzień i %2 dni temu o </translation>
    </message>
    <message>
        <source>d MMMM yyyy at </source>
        <translation>d MMMM yyyy o </translation>
    </message>
    <message>
        <source>Mail client was not specified. Visit the configuration section</source>
        <translation>Klient e-mail nie został skonfigurowany. Sprawdź sekcję konfiguracji</translation>
    </message>
    <message>
        <source>Could not spawn Mail client process. Check if the Mail client is functional</source>
        <translation>Nie mogę przekazać polecenia do klienta e-mail. Sprawdź czy klient pracuje prawidłowo</translation>
    </message>
    <message>
        <source>Look</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Rozmowa</translation>
    </message>
    <message>
        <source>Headers and separators</source>
        <translation>Nagłówki i separatory</translation>
    </message>
    <message>
        <source>Chat header separators height</source>
        <translation>Wysokość separatora nagłówków</translation>
    </message>
    <message>
        <source>Message separators height</source>
        <translation>Wysokość separatora wiadomości</translation>
    </message>
    <message>
        <source>Remove chat header repetitions</source>
        <translation>Usuń powtarzające się nagłówki</translation>
    </message>
    <message>
        <source>Interval between header removal</source>
        <translation>Czas, po jakim nagłówek zostanie powtórzony</translation>
    </message>
    <message>
        <source>Server time</source>
        <translation>Czas serwera</translation>
    </message>
    <message>
        <source>Remove server time</source>
        <translation>Usuń czas serwera</translation>
    </message>
    <message>
        <source>Maximum time difference</source>
        <translation>Maksymalna różnica czasu</translation>
    </message>
    <message>
        <source>Window title</source>
        <translation>Tytuł okna</translation>
    </message>
    <message>
        <source>Chat window title syntax</source>
        <translation>Składnia tytułu okna</translation>
    </message>
    <message>
        <source>Conference window title prefix</source>
        <translation>Prefiks tytułu okna konferencji</translation>
    </message>
    <message>
        <source>Conference window title syntax</source>
        <translation>Składnia tytułu okna konferencji</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Język</translation>
    </message>
    <message>
        <source>Choose your language</source>
        <translation>Wybierz język</translation>
    </message>
    <message>
        <source>Updates</source>
        <translation>Aktualizacje</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Sprawdzaj aktualizacje</translation>
    </message>
    <message>
        <source>Automatically checks whether a new version is available</source>
        <translation>Automatycznie sprawdza czy jest dostępna nowa wersja</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Aplikacje</translation>
    </message>
    <message>
        <source>WWW browser</source>
        <translation>Przeglądarka WWW</translation>
    </message>
    <message>
        <source>Choose your browser</source>
        <translation>Wybierz przeglądarkę</translation>
    </message>
    <message>
        <source>Specify path</source>
        <translation>Podaj ścieżkę</translation>
    </message>
    <message>
        <source>Konqueror</source>
        <translation>Konqueror</translation>
    </message>
    <message>
        <source>Opera</source>
        <translation>Opera</translation>
    </message>
    <message>
        <source>Mozilla</source>
        <translation>Mozilla</translation>
    </message>
    <message>
        <source>Mozilla Firefox</source>
        <translation>Mozilla Firefox</translation>
    </message>
    <message>
        <source>Dillo</source>
        <translation>Dillo</translation>
    </message>
    <message>
        <source>Galeon</source>
        <translation>Galeon</translation>
    </message>
    <message>
        <source>Safari</source>
        <translation>Safari</translation>
    </message>
    <message>
        <source>Custom browser</source>
        <translation>Ścieżka</translation>
    </message>
    <message>
        <source>Write specific path to your browser</source>
        <translation>Podaj ścieżkę do przeglądarki</translation>
    </message>
    <message>
        <source>e-mail client</source>
        <translation>Klient poczty</translation>
    </message>
    <message>
        <source>Choose your e-mail client</source>
        <translation>Wybierz klienta poczty</translation>
    </message>
    <message>
        <source>Choose your email client</source>
        <translation>Wybierz klienta poczty</translation>
    </message>
    <message>
        <source>KMail</source>
        <translation>KMail</translation>
    </message>
    <message>
        <source>Thunderbird</source>
        <translation>Thunderbird</translation>
    </message>
    <message>
        <source>SeaMonkey</source>
        <translation>SeaMonkey</translation>
    </message>
    <message>
        <source>Evolution</source>
        <translation>Evolution</translation>
    </message>
    <message>
        <source>Custom e-mail client</source>
        <translation>Ścieżka</translation>
    </message>
    <message>
        <source>Write specific path to your email client</source>
        <translation>Podaj ścieżkę do klienta poczty</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Zaawansowane</translation>
    </message>
    <message>
        <source>Parser</source>
        <translation>Parser</translation>
    </message>
    <message>
        <source>Allow executing commands by parser</source>
        <translation>Zezwól na wykonywanie komend przez parser</translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation>Debugowanie</translation>
    </message>
    <message>
        <source>Debugging mask</source>
        <translation>Maska debugowania</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message>
        <source>Gadu-Gadu</source>
        <translation>Gadu-Gadu</translation>
    </message>
    <message>
        <source>User data</source>
        <translation>Dane użytkownika</translation>
    </message>
    <message>
        <source>UIN</source>
        <translation>Numer GG</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Nick</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Serwer</translation>
    </message>
    <message>
        <source>Servers properties</source>
        <translation>Właściwości serwera</translation>
    </message>
    <message>
        <source>Use default servers</source>
        <translation>Użyj domyślnych serwerów</translation>
    </message>
    <message>
        <source>IP Addresses</source>
        <translation>Adresy IP</translation>
    </message>
    <message>
        <source>You can specify which GG servers to use. Separate every server using semicolon (for example: 91.197.13.26;91.197.13.24;91.197.13.29;91.197.13.6)</source>
        <translation>Możesz podać listę serwerów, z jakich chcesz korzystać. Oddziel je średnikiem (na przykład: 91.197.13.26;91.197.13.24;91.197.13.29;91.197.13.6)</translation>
    </message>
    <message>
        <source>Port to connect to servers</source>
        <translation>Port połączenia z serwerami</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatycznie</translation>
    </message>
    <message>
        <source>8074</source>
        <translation>8074</translation>
    </message>
    <message>
        <source>443</source>
        <translation>443</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Serwer proxy</translation>
    </message>
    <message>
        <source>Use proxy server</source>
        <translation>Używaj serwera proxy</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Host</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Użytkownik</translation>
    </message>
    <message>
        <source>Contacts</source>
        <translation>Kontakty</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtry</translation>
    </message>
    <message>
        <source>Show offline contacts</source>
        <translation>Pokaż niedostępne kontakty</translation>
    </message>
    <message>
        <source>Show contacts that are blocked</source>
        <translation>Pokaż blokowane kontakty</translation>
    </message>
    <message>
        <source>Show contacts which are blocking me</source>
        <translation>Pokaż kontakty, przez które jesteś blokowany</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Nieznane</translation>
    </message>
    <message>
        <source>Ignore messages from anonymous users</source>
        <translation>Ignoruj wiadomości od nieznanych użytkowników</translation>
    </message>
    <message>
        <source>Ignore messages from anonymous users also in conferences</source>
        <translation>Ignoruj wiadomości od nieznanych użytkowników także w konferencjach</translation>
    </message>
    <message>
        <source>Ignore richtext from anonymous users</source>
        <translation>Ignoruj formatowane wiadomości od nieznanych użytkowników</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Private status</source>
        <translation>Tylko dla znajomych</translation>
    </message>
    <message>
        <source>When enabled, you&apos;re visible only to users on your list</source>
        <translation>Gdy włączone, jesteś widoczny tylko dla użytkowników z twojej listy</translation>
    </message>
    <message>
        <source>Descirption</source>
        <translation>Opis</translation>
    </message>
    <message>
        <source>On startup, set</source>
        <translation>Na starcie ustaw</translation>
    </message>
    <message>
        <source>Choose status which will be set on startup</source>
        <translation>Wybierz status, jaki będzie ustawiony na starcie programu</translation>
    </message>
    <message>
        <source>Last status</source>
        <translation>Ostatni status</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Dostępny</translation>
    </message>
    <message>
        <source>Online (d.)</source>
        <translation>Dostępny z opisem</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Zajęty</translation>
    </message>
    <message>
        <source>Busy (d.)</source>
        <translation>Zajęty z opisem</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Ukryty</translation>
    </message>
    <message>
        <source>Invisible (d.)</source>
        <translation>Ukryty z opisem</translation>
    </message>
    <message>
        <source>Offline (d.)</source>
        <translation>Niedostępny z opisem</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Niedostępny</translation>
    </message>
    <message>
        <source>On startup, set last description</source>
        <translation>Na starcie ustaw ostatni opis</translation>
    </message>
    <message>
        <source>Last decription will be set on startup</source>
        <translation>Ostatni opis będzie ustawiony na starcie programu</translation>
    </message>
    <message>
        <source>On startup, set description</source>
        <translation>Na starcie ustaw opis</translation>
    </message>
    <message>
        <source>Define description which will be set on startup</source>
        <translation>Podaj opis, jaki będzie ustawiony na starcie programu</translation>
    </message>
    <message>
        <source>On shutdown, keep current description</source>
        <translation>Pozostaw opis po zamknięciu programu</translation>
    </message>
    <message>
        <source>Current description will be set on shutdown</source>
        <translation>Aktualny opis będzie ustawiony przy wychodzeniu z programu</translation>
    </message>
    <message>
        <source>On shutdown, set description</source>
        <translation>Przy wyłączaniu ustaw opis</translation>
    </message>
    <message>
        <source>Define description which will be set on shutdown</source>
        <translation>Podaj opis jaki będzie ustawiony przy wyłączaniu programu</translation>
    </message>
    <message>
        <source>Number of kept descriptions</source>
        <translation>Liczba zachowywanych opisów</translation>
    </message>
    <message>
        <source>Allow using variables in status</source>
        <translation>Zezwól na stosowanie zmiennych w opisie</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Schemat</translation>
    </message>
    <message>
        <source>Choose Qt style</source>
        <translation>Wybierz styl Qt</translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation>Zestaw ikon</translation>
    </message>
    <message>
        <source>Choose icon theme</source>
        <translation>Wybierz zestaw ikon</translation>
    </message>
    <message>
        <source>Icon paths</source>
        <translation>Ścieżki do zestawów</translation>
    </message>
    <message>
        <source>Definie icons paths</source>
        <translation>Podaj ścieżki do zestawów</translation>
    </message>
    <message>
        <source>Show status changing button</source>
        <translation>Pokaż przycisk zmiany statusu</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Kolory</translation>
    </message>
    <message>
        <source>Chat window</source>
        <translation>Okno rozmowy</translation>
    </message>
    <message>
        <source>Text edit</source>
        <translation>Okno edycji</translation>
    </message>
    <message>
        <source>My messages</source>
        <translation>Moje wiadomości</translation>
    </message>
    <message>
        <source>User messages</source>
        <translation>Wiadomości kontaktu</translation>
    </message>
    <message>
        <source>My font</source>
        <translation>Moja czcionka</translation>
    </message>
    <message>
        <source>User font</source>
        <translation>Czcionka kontaktu</translation>
    </message>
    <message>
        <source>My nick</source>
        <translation>Mój nick</translation>
    </message>
    <message>
        <source>User nick</source>
        <translation>Nick kontaktu</translation>
    </message>
    <message>
        <source>Userbox</source>
        <translation>Lista kontaktów</translation>
    </message>
    <message>
        <source>Background</source>
        <translation>Tło</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>Czcionka</translation>
    </message>
    <message>
        <source>Descriptions font</source>
        <translation>Czcionka opisu</translation>
    </message>
    <message>
        <source>Information Panel</source>
        <translation>Panel informacyjny</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Czcionki</translation>
    </message>
    <message>
        <source>Font in panel</source>
        <translation>Czcionki panelu</translation>
    </message>
    <message>
        <source>New messages notifications</source>
        <translation>Powiadomienie o nowej wiadomości</translation>
    </message>
    <message>
        <source>Activate windows with new messages</source>
        <translation>Aktywuj okna z nowymi wiadomościami</translation>
    </message>
    <message>
        <source>Flash chat title on new message</source>
        <translation>Mrugaj tytułem okna gdy nadejdzie nowa wiadomość</translation>
    </message>
    <message>
        <source>Show number of new messages on chat title</source>
        <translation>Pokazuj liczbę nowych wiadomości w tytule okna</translation>
    </message>
    <message>
        <source>Nice date format</source>
        <translation>Elegancki format daty</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Styl</translation>
    </message>
    <message>
        <source>Choose style of chat window</source>
        <translation>Wybierz styl rozmowy</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Podgląd</translation>
    </message>
    <message>
        <source>Emoticons</source>
        <translation>Emotikony</translation>
    </message>
    <message>
        <source>Choose emoticons style</source>
        <translation>Wybierz styl emotikon</translation>
    </message>
    <message>
        <source>Animated</source>
        <translation>Animowane</translation>
    </message>
    <message>
        <source>Static</source>
        <translation>Statyczne</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <source>Emoticons theme</source>
        <translation>Zestaw</translation>
    </message>
    <message>
        <source>Choose emoticons theme</source>
        <translation>Wybierz zestaw emotikon</translation>
    </message>
    <message>
        <source>Emoticons paths</source>
        <translation>Ścieżki do zestawów</translation>
    </message>
    <message>
        <source>Define emoticons paths</source>
        <translation>Podaj ścieżki do zestawów emotikon</translation>
    </message>
    <message>
        <source>Advanced...</source>
        <translation>Zaawansowane...</translation>
    </message>
    <message>
        <source>Display group tabs</source>
        <translation>Wyświetlaj zakładki grup</translation>
    </message>
    <message>
        <source>Displays group tabs on userbox</source>
        <translation>Wyświetla zakładki grup przy liście kontaktów</translation>
    </message>
    <message>
        <source>Show available contacts in bold</source>
        <translation>Użyj pogrubionej czcionki dla dostępnych kontaktów</translation>
    </message>
    <message>
        <source>Displays users that are not offline using a bold font</source>
        <translation>Wyświetla użytkowników, którzy są dostępni, używając pogrubionej czcionki</translation>
    </message>
    <message>
        <source>Align contact icon to</source>
        <translation>Ustawienie ikon kontaktów</translation>
    </message>
    <message>
        <source>Align icon next to contact name</source>
        <translation>Ustawienie ikon kontaktów w stosunku do nazw</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Góra</translation>
    </message>
    <message>
        <source>Center</source>
        <translation>Środek</translation>
    </message>
    <message>
        <source>Column count</source>
        <translation>Liczba kolumn</translation>
    </message>
    <message>
        <source>Number of columns displays in userbox</source>
        <translation>Liczba kolumn, na które zostanie podzielona lista kontaktów w głównym oknie</translation>
    </message>
    <message>
        <source>Tool tip style</source>
        <translation>Styl podpowiedzi kontaktu</translation>
    </message>
    <message>
        <source>Choose userbox tool-tip style</source>
        <translation>Wybierz styl podpowiedzi na temat kontaktów z listy</translation>
    </message>
    <message>
        <source>Descriptions</source>
        <translation>Opisy</translation>
    </message>
    <message>
        <source>Show descriptions</source>
        <translation>Pokazuj opisy</translation>
    </message>
    <message>
        <source>Displays descriptions in userbox</source>
        <translation>Wyświetla opisy na liście kontaktów</translation>
    </message>
    <message>
        <source>Allow multiline descriptions</source>
        <translation>Zezwól na wielolinijkowe opisy</translation>
    </message>
    <message>
        <source>Dislpays multiline descriptions in userbox</source>
        <translation>Wyświetla opisy składające się z wielu linii na liście kontaktów</translation>
    </message>
    <message>
        <source>Use background image</source>
        <translation>Użyj obrazka jako tło</translation>
    </message>
    <message>
        <source>Background file</source>
        <translation>Plik tła</translation>
    </message>
    <message>
        <source>Define background file for userbox</source>
        <translation>Podaj plik, który będzie wyświetlany jako tło dla listy kontaktów</translation>
    </message>
    <message>
        <source>Display style</source>
        <translation>Styl wyświetlania</translation>
    </message>
    <message>
        <source>Choose userbox background style</source>
        <translation>Wybierz styl, z jakim będzie wyświetlane tło listy kontaktów</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Kafelki</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Wycentrowany</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Rozciągnięty</translation>
    </message>
    <message>
        <source>Show information panel</source>
        <translation>Pokazuj panel informacyjny</translation>
    </message>
    <message>
        <source>Show vertical scrollbar</source>
        <translation>Pokazuj pionowy pasek przewijania</translation>
    </message>
    <message>
        <source>Show vertical scrollbar in information panel</source>
        <translation>Pokazuje pionowy pasek przewijania w panelu informacyjnym</translation>
    </message>
    <message>
        <source>Show emoticons in panel</source>
        <translation>Pokazuj emotikonki</translation>
    </message>
    <message>
        <source>Show emoticons in information panel</source>
        <translation>Pokazuje emotikonki w panelu informacyjnym</translation>
    </message>
    <message>
        <source>Choose information panel style</source>
        <translation>Wybierz styl panelu informacyjnego</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <source>Configuration</source>
        <translation>Konfiguracja</translation>
    </message>
    <message>
        <source>Add user</source>
        <translation>Dodaj kontakt</translation>
    </message>
    <message>
        <source>Manage modules</source>
        <translation>Zarządzaj modułami</translation>
    </message>
    <message>
        <source>Open chat with...</source>
        <translation>Rozpocznij rozmowę z ...</translation>
    </message>
    <message>
        <source>Userlist</source>
        <translation>Lista kontaktów</translation>
    </message>
    <message>
        <source>Remove from userlist</source>
        <translation>Usuń z listy kontaktów</translation>
    </message>
    <message>
        <source>Search this user in directory</source>
        <translation>Znajdź wybrany kontakt w katalogu</translation>
    </message>
    <message>
        <source>Show / hide offline users</source>
        <translation>Pokaż / ukryj kontakty niedostępne</translation>
    </message>
    <message>
        <source>Show / hide users without description</source>
        <translation>Pokaż / ukryj kontakty bez opisu</translation>
    </message>
    <message>
        <source>New line / send message</source>
        <translation>Nowa linia / wyślij wiadomość</translation>
    </message>
    <message>
        <source>Clear chat</source>
        <translation>Wyczyść rozmowę</translation>
    </message>
    <message>
        <source>Close chat</source>
        <translation>Zamknij rozmowę</translation>
    </message>
    <message>
        <source>Bold text</source>
        <translation>Pogrubienie</translation>
    </message>
    <message>
        <source>Italic text</source>
        <translation>Kursywa</translation>
    </message>
    <message>
        <source>Underline text</source>
        <translation>Podkreślenie</translation>
    </message>
    <message>
        <source>Behaviour</source>
        <translation>Zachowanie</translation>
    </message>
    <message>
        <source>Remember chat windows positions</source>
        <translation>Zapamiętaj pozycje okien rozmowy</translation>
    </message>
    <message>
        <source>Open chat window on new message</source>
        <translation>Otwórz okno rozmowy gdy nadejdzie nowa wiadomość</translation>
    </message>
    <message>
        <source>Open chat window when comes new message</source>
        <translation>Otwiera okno rozmowy gdy nadejdzie nowa wiadomość od kontaktu</translation>
    </message>
    <message>
        <source>Open chat window only when I&apos;m online</source>
        <translation>Otwórz okno rozmowy tylko gdy jestem dostępny</translation>
    </message>
    <message>
        <source>Open chat window on new message only when online</source>
        <translation>Otwiera okno rozmowy tylko gdy jesteś dostępny</translation>
    </message>
    <message>
        <source>Wait for message delivery</source>
        <translation>Czekaj na potwierdzenie otrzymania wiadomości</translation>
    </message>
    <message>
        <source>Wait for confirmation from server during send messages</source>
        <translation>Nie pozwala na wysłanie nowej wiadomości jeżeli nie zostało otrzymane potwierdzenie odebrania poprzedniej</translation>
    </message>
    <message>
        <source>&apos;Enter&apos; in chat send message</source>
        <translation>&apos;Enter&apos; w oknie rozmowy wysyła wiadomość</translation>
    </message>
    <message>
        <source>Confirm clearing chat window</source>
        <translation>Potwierdzaj czyszczenie rozmowy</translation>
    </message>
    <message>
        <source>Ask before clearing chat window</source>
        <translation>Pyta przed wyczyszczeniem rozmowy</translation>
    </message>
    <message>
        <source>Save opened windows on exit</source>
        <translation>Zapamiętaj otwarte okna przy zamykaniu programu</translation>
    </message>
    <message>
        <source>Save opened chat windows when exiting</source>
        <translation>Zapamiętuje, które okna były otwarte przy wychodzeniu z programu</translation>
    </message>
    <message>
        <source>Closing</source>
        <translation>Zamykanie</translation>
    </message>
    <message>
        <source>Block window close on new message</source>
        <translation>Blokuj zamykanie okna, gdy nadejdzie nowa wiadomość</translation>
    </message>
    <message>
        <source>Block chat window when comes new message</source>
        <translation>Uniemożliwia zamknięcie okna na pewien czas po otrzymaniu nowej wiadomości</translation>
    </message>
    <message>
        <source>Max time to block window close</source>
        <translation>Maksymalny czas blokowania</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Wiadomości</translation>
    </message>
    <message>
        <source>Message pruning</source>
        <translation>Limit wyświetlanych wiadomości</translation>
    </message>
    <message>
        <source>Automatically prune chat messages</source>
        <translation>Limituj liczbę wyświetlanych wiadomości</translation>
    </message>
    <message>
        <source>If enabled, messages are pruning</source>
        <translation>Gdy włączone, liczba wyświetlanych wiadomości w oknie jest limitowana</translation>
    </message>
    <message>
        <source>Reduce the number of visible messages in chat window to</source>
        <translation>Maksymalna liczba wiadomości w oknie rozmowy</translation>
    </message>
    <message>
        <source>Number of visible messages</source>
        <translation>Liczba widzianych wiadomości</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Obrazki</translation>
    </message>
    <message>
        <source>Max image size</source>
        <translation>Maksymalny rozmiar obrazka</translation>
    </message>
    <message>
        <source>Maximum image size that we want to receive</source>
        <translation>Maksymalny akceptowalny rozmiar otrzymywanego obrazka</translation>
    </message>
    <message>
        <source>Receive images during invisibility</source>
        <translation>Odbieraj obrazki także gdy jestem ukryty</translation>
    </message>
    <message>
        <source>Receiving images during invisibility is allowed</source>
        <translation>Zezwala na odbieranie obrazków w czasie bycia ukrytym</translation>
    </message>
    <message>
        <source>Limit numbers of image recevied per minute</source>
        <translation>Limit liczby obrazków odbieranych w ciągu minuty</translation>
    </message>
    <message>
        <source>Define limit of images received per minute</source>
        <translation>Limituj liczbę obrazków, jaka może zostać odebrana w czasie jednej minuty</translation>
    </message>
    <message>
        <source>Link folding</source>
        <translation>Skracaj linki</translation>
    </message>
    <message>
        <source>Automatically fold links</source>
        <translation>Automatycznie skracaj linki</translation>
    </message>
    <message>
        <source>Fold links longer than</source>
        <translation>Skracaj linki dłuższe niż</translation>
    </message>
    <message>
        <source>Displays information panel below userbox</source>
        <translation>Wyświetlaj panel informacyjny pod listą kontaktów</translation>
    </message>
    <message>
        <source>default</source>
        <translation>Domyślny</translation>
    </message>
    <message>
        <source>Syntax: %s - status, %d - description, %i - ip, %n - nick, %a - altnick, %f - first name
%r - surname, %m - mobile, %u - uin, %g - group, %o - return _space_ if user doesn&apos;t have us in userlist
%h - gg version, %v - revDNS, %p - port, %e - email, %x - max image size
</source>
        <translation>Składnia: %s - status, %d - opis, %i - IP, %n - nick, %a - wyświetl, %f - imię,
%r - nazwisko, %m - telefon, %u - nr GG, %g - grupa, %o - zwraca spację jeżeli kontakt nie ma cię na liście,
%v - DNS, %h - wersja gg, %p - port %e - email, %x - max rozmiar obrazka</translation>
    </message>
    <message>
        <source>Syntax: %s - status, %d - description, %i - ip, %n - nick, %a - altnick, %f - first name
%r - surname, %m - mobile, %u - uin, %g - group, %o - return _space_ if user doesn&apos;t have us in userlist
%h - gg version, %v - revDNS, %p - port, %e - email, %x - max image size,
#{protocol} - protocol that triggered event,
#{event} - name of event,
</source>
        <translation>Składnia: %s - status, %d - opis, %i - IP, %n - nick, %a - wyświetl, %f - imię,
%r - nazwisko, %m - telefon, %u - nr GG, %g - grupa, %o - zwraca spację jeżeli kontakt nie ma cię na liście,
%v - DNS, %h - wersja gg, %p - port %e - email, %x - max rozmiar obrazka
#{protocol} - nazwa protokołu, który wywołał zdarzenie,
#{event} - nazwa zdarzenia</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Dane kontaktu</translation>
    </message>
    <message>
        <source>Opera (new tab)</source>
        <translation>Opera (nowa karta)</translation>
    </message>
    <message>
        <source>Set invisible if last status was &apos;Offline&apos;</source>
        <translation>Ustaw niewidzialny, jeżeli ostatni status to &apos;Niedostępny&apos;</translation>
    </message>
    <message>
        <source>Syntax: %s - status, %d - description, %i - ip, %n - nick, %a - altnick, %f - first name
%r - surname, %m - mobile, %u - uin, %g - group, %o - return _space_ if user doesn&apos;t have us in userlist
%h - gg version, %v - revDNS, %p - port, %e - email, %x - max image size,
#{message} - message content,
#{backgroundColor} - background color of message,
#{fontColor} - font color of message,
#{nickColor} - font color of nick,
#{sentDate} - when message was sent,
#{receivedDate} - when message was received,
#{separator} - separator between messages,
&lt;kadu:header&gt;text&lt;/kadu:header&gt; - text will not be displayed in &apos;Remove repeated headers&apos; mode
</source>
        <translation>Składnia: %s - status, %d - opis, %i - IP, %n - nick, %a - wyświetl, %f - imię,
%r - nazwisko, %m - telefon, %u - nr GG, %g - grupa, %o - zwraca spację jeżeli kontakt nie ma cię na liście,
%v - DNS, %h - wersja gg, %p - port %e - email, %x - max rozmiar obrazka,
#{message} - treść wiadomości,
#{backgroundColor} - kolor tła,
#{fontColor} - kolor czcionki,
#{nickColor} - kolor czcionki pseudonimu,
#{sentDate} - czas wysłania wiadomości,
#{receivedDate} - czas odebrania wiadomości,
#{separator} - separator wiadomości
&lt;kadu:header&gt;tekst&lt;/kadu:header&gt; - tekst nie będzie wyswietlany w trybie &apos;Usuń powtarzające się nagłówki&quot;
</translation>
    </message>
    <message>
        <source>Startup</source>
        <translation>Autostart</translation>
    </message>
    <message>
        <source>Start on startup</source>
        <translation>Uruchamiaj przy starcie systemu</translation>
    </message>
    <message>
        <source>Automatically start on system startup</source>
        <translation>Automatycznie uruchamia Kadu kiedy system startuje</translation>
    </message>
    <message>
        <source>Displays messages from anonymous users without formatting (colors, images, font weight...) Text is plain black.</source>
        <translation>Wyświetla tekst od anonimów bez formatowania (kolory, obrazki, czcionka).</translation>
    </message>
    <message>
        <source>Display dates is nice format, like Today, Yesterday or Friday</source>
        <translation>Wyświetla daty w eleganckim formacie, na przykład: Dzisiaj, Wczoraj, Piątek</translation>
    </message>
</context>
<context>
    <name>About</name>
    <message>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <source>A&amp;uthors</source>
        <translation>A&amp;utorzy</translation>
    </message>
    <message>
        <source>&amp;Thanks</source>
        <translation>&amp;Podziękowania</translation>
    </message>
    <message>
        <source>&amp;ChangeLog</source>
        <translation>&amp;Lista zmian</translation>
    </message>
    <message>
        <source>&amp;License</source>
        <translation>L&amp;icencja</translation>
    </message>
</context>
<context>
    <name>ChatManager</name>
    <message>
        <source>%1 sends message</source>
        <translation>%1 wysyła wiadomość</translation>
    </message>
    <message>
        <source>Clear messages in chat window</source>
        <translation>Wyczyść wiadomości w historii rozmowy</translation>
    </message>
    <message>
        <source>Insert emoticon</source>
        <translation>Wstaw emotikonę</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>Wstaw obraz</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Pogrubienie</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kursywa</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Podkreślenie</translation>
    </message>
    <message>
        <source>Change color</source>
        <translation>Zmiana koloru</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Wyślij</translation>
    </message>
    <message>
        <source>Insert emoticon - enable in configuration</source>
        <translation>Wstaw emotikonę - uaktywnij w konfiguracji</translation>
    </message>
    <message>
        <source>&amp;Chat</source>
        <translation>&amp;Rozmowa</translation>
    </message>
    <message>
        <source>Anonymous users will be unblocked after restarting Kadu</source>
        <translation>Anonimowe kontakty będą odblokowane po restarcie Kadu</translation>
    </message>
    <message>
        <source>Search this user in directory</source>
        <translation>Znajdź wybrany kontakt w katalogu</translation>
    </message>
    <message>
        <source>Ignore user</source>
        <translation>Ignoruj kontakt</translation>
    </message>
    <message>
        <source>Block user</source>
        <translation>Blokuj kontakt</translation>
    </message>
    <message>
        <source>Open chat with...</source>
        <translation>Rozpocznij rozmowę z ...</translation>
    </message>
</context>
<context>
    <name>ChatWidget</name>
    <message>
        <source>Leave conference</source>
        <translation>Opuść konferencję</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>Wstaw obraz</translation>
    </message>
    <message>
        <source>This file is not readable</source>
        <translation>Pliku nie można odczytać</translation>
    </message>
    <message>
        <source>This file is too big (%1 &gt;= %2)</source>
        <translation>Plik jest za duży (%1 &gt;= %2)</translation>
    </message>
    <message>
        <source>This file is too big for %1.
Do you really want to send this image?
</source>
        <translation>Rozmiar pliku jest za duży dla %1.
Czy na pewno chcesz wysłać ten obrazek?
</translation>
    </message>
    <message>
        <source>This file is too big for %1 of %2 contacts.
Do you really want to send this image?
Some of them probably will not get it.</source>
        <translation>Rozmiar pliku jest za duży dla %1 z %2 kontaktów.
Czy na pewno chcesz wysłać ten obrazek?
Prawdopodobnie nie zostanie on wszystkim dostarczony.</translation>
    </message>
    <message>
        <source>Conference with </source>
        <translation>Konferencja z </translation>
    </message>
    <message>
        <source>Chat with </source>
        <translation>Rozmowa z </translation>
    </message>
    <message>
        <source>Chat window will be cleared. Continue?</source>
        <translation>Okno rozmowy zostanie wyczyszczone. Kontynuować?</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Wyślij</translation>
    </message>
    <message>
        <source>Cannot send message while being offline.</source>
        <translation>Nie mogę wysłać wiadomości dopóki nie jesteś połączony.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuluj</translation>
    </message>
    <message>
        <source>All messages received in this conference will be ignored
from now on. Are you sure you want to leave this conference?</source>
        <translation>Wszystkie wiadomości z tej konferencji będą od teraz ignorowane.
Na pewno chcesz opuścić tę konferencję?</translation>
    </message>
</context>
<context>
    <name>ChatWindow</name>
    <message>
        <source>New message received, close window anyway?</source>
        <translation>Odebrano nową wiadomość, czy na pewno zamknąć okno?</translation>
    </message>
</context>
<context>
    <name>ChooseDescription</name>
    <message>
        <source>Select description</source>
        <translation>Podaj opis</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuluj</translation>
    </message>
</context>
<context>
    <name>ConfigurationWindow</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Zastosuj</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>CustomInput</name>
    <message>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Ponów</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Wytnij</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Wklej</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Zaznacz wszystko</translation>
    </message>
</context>
<context>
    <name>GaduFormater</name>
    <message>
        <source>###IMAGE BLOCKED###</source>
        <translation>###ZDJĘCIE ZABLOKOWANE###</translation>
    </message>
    <message>
        <source>###IMAGE TOO BIG###</source>
        <translation>###ZDJĘCIE ZA DUŻE###</translation>
    </message>
</context>
<context>
    <name>GaduProtocol</name>
    <message>
        <source>I am busy.</source>
        <translation>Jestem zajęty.</translation>
    </message>
    <message>
        <source>Unable to connect, server has not been found</source>
        <translation>Połączenie niemożliwe, serwer nie znaleziony</translation>
    </message>
    <message>
        <source>Unable to connect</source>
        <translation>Połączenie niemożliwe</translation>
    </message>
    <message>
        <source>Unable to connect, server has returned unknown data</source>
        <translation>Połączenie niemożliwe, serwer odpowiedział nieznane dane</translation>
    </message>
    <message>
        <source>Unable to connect, connection break during reading</source>
        <translation>Połączenie niemożliwe, połączenie przerwane w czasie odczytu</translation>
    </message>
    <message>
        <source>Unable to connect, connection break during writing</source>
        <translation>Połączenie niemożliwe, połączenie przerwane w czasie zapisu</translation>
    </message>
    <message>
        <source>Unable to connect, incorrect password</source>
        <translation>Połączenia niemożliwe, nieprawidłowe hasło</translation>
    </message>
    <message>
        <source>Unable to connect, error of negotiation TLS</source>
        <translation>Połączenie niemożliwe, błąd negocjacji TLS</translation>
    </message>
    <message>
        <source>Connection timeout!</source>
        <translation>Przekroczenie czasu połączenia!</translation>
    </message>
    <message>
        <source>Disconnection has occured</source>
        <translation>Nastąpiło rozłączenie</translation>
    </message>
    <message>
        <source>UIN or password not set!</source>
        <translation>Nie podałeś nr GG lub hasła!</translation>
    </message>
    <message>
        <source>Please change your email in &quot;Change password / email&quot; window. Leave new password field blank.</source>
        <translation>Zmień swój e-mail w oknie &quot;Zmień hasło / e-mail&quot;. Pole nowe hasło pozostaw puste.</translation>
    </message>
    <message>
        <source>Unable to connect, servers are down</source>
        <translation>Połączenie nie możliwe, serwery są niedostępne</translation>
    </message>
    <message>
        <source>Connection will be stopped
Your password is incorrect!</source>
        <translation>Połączenie zostanie przerwane
Twoje hasło jest niepoprawne!</translation>
    </message>
    <message>
        <source>Too many connection attempts with bad password!</source>
        <translation>Zbyt wiele połączeń z użyciem błędnego hasła!</translation>
    </message>
    <message>
        <source>Connection will be stopped
Too many attempts with bad password</source>
        <translation>Połączenie zostanie przerwane
Zbyt wiele prób połączeń z niepoprawnym hasłem</translation>
    </message>
    <message>
        <source>Filtered message too long (%1&gt;=%2)</source>
        <translation>Filtrowana  wiadomość zbyt długa (%1&gt;=%2)</translation>
    </message>
    <message>
        <source>Message blocked.</source>
        <translation>Wiadomość zablokowana.</translation>
    </message>
    <message>
        <source>Messagebox full.</source>
        <translation>Skrzynka odbiorcza jest pełna.</translation>
    </message>
    <message>
        <source>Message not delivered.</source>
        <translation>Wiadomość nie dostarczona.</translation>
    </message>
</context>
<context>
    <name>GroupsManager</name>
    <message>
        <source>All</source>
        <translation>Wszyscy</translation>
    </message>
</context>
<context>
    <name>Ignored</name>
    <message>
        <source>Manage ignored users</source>
        <translation>Lista ignorowanych</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Uin</source>
        <translation>Numer GG</translation>
    </message>
    <message>
        <source>This dialog box allows you to manage your ignored contacts.</source>
        <translation>To okno dialogowe pozwala dodawać lub usuwać kontakty, które mają być ignorowane.</translation>
    </message>
    <message>
        <source>Type here the UIN of the person you want to ignore.</source>
        <translation>Wpisz tutaj numer GG osoby, która ma być ignorowana.</translation>
    </message>
    <message>
        <source>Uin:</source>
        <translation>Numer GG: </translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
</context>
<context>
    <name>ImageDialog</name>
    <message>
        <source>Images</source>
        <translation>Obrazki</translation>
    </message>
</context>
<context>
    <name>Kadu</name>
    <message>
        <source>Configuration</source>
        <translation>Konfiguracja</translation>
    </message>
    <message>
        <source>Add user</source>
        <translation>Dodaj kontakt</translation>
    </message>
    <message>
        <source>Kadu: %1</source>
        <translation>Kadu: %1</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Niedostępny</translation>
    </message>
    <message>
        <source>&amp;Exit Kadu</source>
        <translation>&amp;Zakończ Kadu</translation>
    </message>
    <message>
        <source>Show Pending Messages</source>
        <translation>Pokaż otrzymane wiadomości</translation>
    </message>
    <message>
        <source>Notify about user</source>
        <translation>Powiadom o kontakcie</translation>
    </message>
    <message>
        <source>Offline to user</source>
        <translation>Niedostępny dla kontaktu</translation>
    </message>
    <message>
        <source>Manage &amp;ignored</source>
        <translation>Zarządzaj i&amp;gnorowanymi</translation>
    </message>
    <message>
        <source>Personal information</source>
        <translation>Dane osobiste</translation>
    </message>
    <message>
        <source>H&amp;elp</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>A&amp;bout...</source>
        <translation>&amp;O programie...</translation>
    </message>
    <message>
        <source>&amp;Hide Kadu</source>
        <translation>Uk&amp;ryj Kadu</translation>
    </message>
    <message>
        <source>Private</source>
        <translation>Tylko dla znajomych</translation>
    </message>
    <message>
        <source>I&amp;mport / Export userlist</source>
        <translation>I&amp;mport / eksport listy kontaktów</translation>
    </message>
    <message>
        <source>Selected users:
%0will be deleted. Are you sure?</source>
        <translation>Wybrane kontakty:
%0zostaną usunięte.
Czy na pewno tego chcesz?</translation>
    </message>
    <message>
        <source>Hide description</source>
        <translation>Ukryj opis</translation>
    </message>
    <message>
        <source>Search user in directory</source>
        <translation>Znajdź kontakt w katalogu</translation>
    </message>
    <message>
        <source>Copy description</source>
        <translation>Kopiuj opis</translation>
    </message>
    <message>
        <source>Open description link in browser</source>
        <translation>Otwórz odnośnik z opisu w przeglądarce</translation>
    </message>
    <message>
        <source>Copy personal info</source>
        <translation>Kopiuj dane personalne</translation>
    </message>
    <message>
        <source>Contact: %a[ (%u)]
[First name: %f
][Last name: %r
][Mobile: %m
]</source>
        <translation>Kontakt: %a[ (%u)]
[Imię: %f
][Nazwisko: %r
][Telefon: %m
]</translation>
    </message>
    <message>
        <source>Write email message</source>
        <translation>Napisz wiadomość e-mail</translation>
    </message>
    <message>
        <source>Search in directory</source>
        <translation>Znajdź w katalogu</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Hide offline users</source>
        <translation>Ukryj kontakty niedostępne</translation>
    </message>
    <message>
        <source>Show offline users</source>
        <translation>Pokaż kontakty niedostępne</translation>
    </message>
    <message>
        <source>Hide users without description</source>
        <translation>Ukryj kontakty bez opisu</translation>
    </message>
    <message>
        <source>Show users without description</source>
        <translation>Pokaż kontakty bez opisu</translation>
    </message>
    <message>
        <source>Show only online or description buddies</source>
        <translation>Pokaż tylko kontakty dostępne lub z opisem</translation>
    </message>
    <message>
        <source>Show all users</source>
        <translation>Pokaż wszystkie kontakty</translation>
    </message>
    <message>
        <source>Recent chats...</source>
        <translation>Ostatnie rozmowy...</translation>
    </message>
    <message>
        <source>No closed chats found</source>
        <translation>Brak zamkniętych rozmów</translation>
    </message>
    <message>
        <source>Contact data</source>
        <translation>Dane kontaktu</translation>
    </message>
    <message>
        <source>Me</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>Change status</source>
        <translation>Zmiana statusu</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menu</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Dostępny</translation>
    </message>
    <message>
        <source>Online (d.)</source>
        <translation>Dostępny z opisem</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Zajęty</translation>
    </message>
    <message>
        <source>Busy (d.)</source>
        <translation>Zajęty z opisem</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Ukryty</translation>
    </message>
    <message>
        <source>Invisible (d.)</source>
        <translation>Ukryty z opisem</translation>
    </message>
    <message>
        <source>Offline (d.)</source>
        <translation>Niedostępny z opisem</translation>
    </message>
</context>
<context>
    <name>KaduMainWindow</name>
    <message>
        <source>Create new toolbar</source>
        <translation>Utwórz nowy pasek narzędziowy</translation>
    </message>
</context>
<context>
    <name>KaduTabBar</name>
    <message>
        <source>Add new group</source>
        <translation>Dodaj nową grupę</translation>
    </message>
    <message>
        <source>Name of new group:</source>
        <translation>Nazwa nowej grupy:</translation>
    </message>
    <message>
        <source>Add to group %1</source>
        <translation>Dodaj do grupy %1</translation>
    </message>
    <message>
        <source>Move to group %1</source>
        <translation>Przenieś do grupy %1</translation>
    </message>
</context>
<context>
    <name>KaduTextBrowser</name>
    <message>
        <source>Save image</source>
        <translation>Zapisz obrazek</translation>
    </message>
    <message>
        <source>File already exists. Overwrite?</source>
        <translation>Plik już istnieje. Nadpisać?</translation>
    </message>
    <message>
        <source>Cannot save image: %1</source>
        <translation>Nie można zapisać obrazka: %1</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Copy Link</source>
        <translation>Kopiuj link</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation>Kopiuj obrazek</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation>Zapisz obrazek</translation>
    </message>
</context>
<context>
    <name>MainConfigurationWindow</name>
    <message>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <source>Not found</source>
        <translation>Nie znalezione</translation>
    </message>
    <message>
        <source>Kadu configuration</source>
        <translation>Konfiguracja Kadu</translation>
    </message>
    <message>
        <source>Advenced chat&apos;s look configuration</source>
        <translation>Zaawansowana konfiguracja wyglądu okna rozmowy</translation>
    </message>
    <message>
        <source>Your message</source>
        <translation>Wiadomość od Ciebie</translation>
    </message>
    <message>
        <source>Message from Your friend</source>
        <translation>Wiadomość do Ciebie</translation>
    </message>
</context>
<context>
    <name>MessageBox</name>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Tak</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nie</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuluj</translation>
    </message>
</context>
<context>
    <name>ModulesDialog</name>
    <message>
        <source>Manage Modules</source>
        <translation>Zarządca modułów</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informacje</translation>
    </message>
    <message>
        <source>Static</source>
        <translation>Statyczny</translation>
    </message>
    <message>
        <source>Loaded</source>
        <translation>Załadowany</translation>
    </message>
    <message>
        <source>Module name</source>
        <translation>Nazwa modułu</translation>
    </message>
    <message>
        <source>Module type</source>
        <translation>Typ modułu</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Stan</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <source>Dynamic</source>
        <translation>Dynamiczny</translation>
    </message>
    <message>
        <source>Not loaded</source>
        <translation>Niezaładowany</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
    <message>
        <source>&lt;b&gt;Module:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Depends on:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Conflicts with:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Provides:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Author:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Version:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Description:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Moduł:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Wymaga:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Konflikt z:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Dostarcza:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Autor:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Wersja:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Opis:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Hide base modules</source>
        <translation>Ukryj standardowe moduły</translation>
    </message>
    <message>
        <source>&lt;b&gt;Module: &lt;/b&gt;%1&lt;br/&gt;&lt;b&gt;Depends on: &lt;/b&gt;%2&lt;br/&gt;&lt;b&gt;Conflicts with: &lt;/b&gt;%3&lt;br/&gt;&lt;b&gt;Provides: &lt;/b&gt;%4&lt;br/&gt;&lt;b&gt;Author: &lt;/b&gt;%5&lt;br/&gt;&lt;b&gt;Version: &lt;/b&gt;%6&lt;br/&gt;&lt;b&gt;Description: &lt;/b&gt;%7</source>
        <translation>&lt;b&gt;Moduł: &lt;/b&gt;%1&lt;br/&gt;&lt;b&gt;Wymaga: &lt;/b&gt;%2&lt;br/&gt;&lt;b&gt;Konflikt z: &lt;/b&gt;%3&lt;br/&gt;&lt;b&gt;Dostarcza: &lt;/b&gt;%4&lt;br/&gt;&lt;b&gt;Autor: &lt;/b&gt;%5&lt;br/&gt;&lt;b&gt;Wersja: &lt;/b&gt;%6&lt;br/&gt;&lt;b&gt;Opis: &lt;/b&gt;%7</translation>
    </message>
    <message>
        <source>This dialog box allows you to manage installed modules. Modules are responsible for numerous vital features like playing sounds or message encryption.
You can load (or unload) them by double-clicking on their names.</source>
        <translation>To okno dialogowe daje możliwość zarządzania zainstalowanymi modułąmi. Moduły są odpowiedzialne za wiele funkcji takich jak odtwarzanie dźwięków lub szyfrowanie wiadomości.
Jeśli zechcesz włączyć (lub wyłączyć) któryś z nich, wystarczy dwukrotnie kliknąć na jego nazwie. Modułu statycznego nie można wyłączyć.</translation>
    </message>
</context>
<context>
    <name>ModulesManager</name>
    <message>
        <source>&amp;Manage Modules</source>
        <translation>Z&amp;arządca modułów</translation>
    </message>
    <message>
        <source>Required module %1 was not found</source>
        <translation>Wymagany moduł %1 nie został znaleziony</translation>
    </message>
    <message>
        <source>Module %1 is already active</source>
        <translation>Moduł %1 jest aktywny</translation>
    </message>
    <message>
        <source>Cannot load %1 module library.:
%2</source>
        <translation>Nie mogę załadować biblioteki modułu %1:
%2</translation>
    </message>
    <message>
        <source>Module %1 cannot be deactivated because it is used now</source>
        <translation>Moduł %1 nie może być dezaktywowany ponieważ jest obecnie w użyciu</translation>
    </message>
    <message>
        <source>Module %1 conflicts with: %2</source>
        <translation>Moduł %1 koliduje z: %2</translation>
    </message>
    <message>
        <source>Cannot find required functions in module %1.
Maybe it&apos;s not Kadu-compatible Module.</source>
        <translation>Nie znaleziono wymaganych funkcji w module %1.
Być może nie jest to moduł kompatybilny z Kadu.</translation>
    </message>
    <message>
        <source>Module initialization routine for %1 failed.</source>
        <translation>Inicjacja modułu %1 nieudana.</translation>
    </message>
</context>
<context>
    <name>OpenChatWith</name>
    <message>
        <source>Open chat with...</source>
        <translation>Rozpocznij rozmowę z ...</translation>
    </message>
    <message>
        <source>Userlist</source>
        <translation>Lista kontaktów</translation>
    </message>
    <message>
        <source>UIN or nick</source>
        <translation>Numer GG lub pseudonim</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuluj</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
</context>
<context>
    <name>PathListEdit</name>
    <message>
        <source>Select</source>
        <translation>Wybierz</translation>
    </message>
</context>
<context>
    <name>PathListEditWindow</name>
    <message>
        <source>Select paths</source>
        <translation>Wybierz ścieżki</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Zmień</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuluj</translation>
    </message>
    <message>
        <source>Choose a directory</source>
        <translation>Wybierz katalog</translation>
    </message>
</context>
<context>
    <name>PersonalInfoDialog</name>
    <message>
        <source>Personal Information</source>
        <translation>Dane osobiste</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Pseudonim</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Imię</translation>
    </message>
    <message>
        <source>Surname</source>
        <translation>Nazwisko</translation>
    </message>
    <message>
        <source>Gender</source>
        <translation>Płeć</translation>
    </message>
    <message>
        <source>Male</source>
        <translation>Mężczyzna</translation>
    </message>
    <message>
        <source>Female</source>
        <translation>Kobieta</translation>
    </message>
    <message>
        <source>Birthyear</source>
        <translation>Rok urodzenia</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Miejscowość</translation>
    </message>
    <message>
        <source>Family Name</source>
        <translation>Nazwisko rodowe</translation>
    </message>
    <message>
        <source>Family City</source>
        <translation>Miasto rodzinne</translation>
    </message>
    <message>
        <source>This dialog box allows you to manage your personal information, for example your name, surname or age.</source>
        <translation>To okno dialogowe daje możliwość zarządzania Twoimi danymi personalnymi takimi jak imię, nazwisko, wiek, płeć.</translation>
    </message>
    <message>
        <source>Your personal information</source>
        <translation>Twoje dane osobiste</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Zapisz</translation>
    </message>
    <message>
        <source>&amp;Reload</source>
        <translation>&amp;Przeładuj</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Szukaj</translation>
    </message>
    <message>
        <source>&amp;Next results</source>
        <translation>&amp;Następne wyniki</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Pseudonim</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Imię</translation>
    </message>
    <message>
        <source>Surname</source>
        <translation>Nazwisko</translation>
    </message>
    <message>
        <source>Gender</source>
        <translation>Płeć</translation>
    </message>
    <message>
        <source>Male</source>
        <translation>Mężczyzna</translation>
    </message>
    <message>
        <source>Female</source>
        <translation>Kobieta</translation>
    </message>
    <message>
        <source>Birthyear</source>
        <translation>Rok urodzenia</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Miejscowość</translation>
    </message>
    <message>
        <source>Uin</source>
        <translation>Numer GG</translation>
    </message>
    <message>
        <source>Search criteria</source>
        <translation>Kryteria wyszukiwania</translation>
    </message>
    <message>
        <source>&amp;Personal data</source>
        <translation>&amp;Dane osobiste</translation>
    </message>
    <message>
        <source>Search using the personal data typed above (name, nickname)...</source>
        <translation>Szukaj używając danych osobistych wpisanych powyżej...</translation>
    </message>
    <message>
        <source>&amp;Uin number</source>
        <translation>&amp;Numer GG</translation>
    </message>
    <message>
        <source>Search for this UIN exclusively</source>
        <translation>Szukaj podanego numer GG</translation>
    </message>
    <message>
        <source>Only active users</source>
        <translation>Tylko aktywni użytkownicy</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Birth year</source>
        <translation>Rok urodzenia</translation>
    </message>
    <message>
        <source>Searching...</source>
        <translation>Wyszukiwanie...</translation>
    </message>
    <message>
        <source>Done searching</source>
        <translation>Wyszukiwanie zakończone</translation>
    </message>
    <message>
        <source>from</source>
        <translation>od</translation>
    </message>
    <message>
        <source>to</source>
        <translation>do</translation>
    </message>
    <message>
        <source>There were no results of your search</source>
        <translation>Nie było żadnych wyników twojego poszukiwana</translation>
    </message>
    <message>
        <source>Search user in directory</source>
        <translation>Znajdź kontakt w katalogu</translation>
    </message>
    <message>
        <source>Clear results</source>
        <translation>Wyczyść rezultaty</translation>
    </message>
    <message>
        <source>Add selected user</source>
        <translation>Dodaj wybrany kontakt</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>&amp;Chat</source>
        <translation>&amp;Rozmowa</translation>
    </message>
    <message>
        <source>Cannot search contacts in offline mode</source>
        <translation>Nie mogę szukać kontaktów w trybie &quot;niedostępny&quot;</translation>
    </message>
</context>
<context>
    <name>SelectFile</name>
    <message>
        <source>Insert image</source>
        <translation>Wstaw obraz</translation>
    </message>
    <message>
        <source>Select File</source>
        <translation>Wybierz plik</translation>
    </message>
    <message>
        <source>Select audio File</source>
        <translation>Wybierz plik dźwiękowy</translation>
    </message>
</context>
<context>
    <name>SelectFont</name>
    <message>
        <source>Select</source>
        <translation>Wybierz</translation>
    </message>
</context>
<context>
    <name>SyntaxEditor</name>
    <message>
        <source>Edit</source>
        <translation>Edytuj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Unable to remove syntax: %1</source>
        <translation>Niemożliwe usunięcie składni: %1</translation>
    </message>
</context>
<context>
    <name>SyntaxEditorWindow</name>
    <message>
        <source>Kadu syntax editor</source>
        <translation>Edytor składni Kadu</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>New syntax name</source>
        <translation>Nowa nazwa składni</translation>
    </message>
    <message>
        <source>Enter new syntax name</source>
        <translation>Wpisz nową nazwę składni</translation>
    </message>
    <message>
        <source>Syntax %1 already exists and cannot be modified</source>
        <translation>Składnia %1 już istnieje i nie może być zmodyfikowana</translation>
    </message>
    <message>
        <source>Overwrite %1 syntax?</source>
        <translation>Nadpisać składnie %1?</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Podgląd</translation>
    </message>
    <message>
        <source>Save as...</source>
        <translation>Zapisz jako...</translation>
    </message>
</context>
<context>
    <name>TokenDialog</name>
    <message>
        <source>Read this code ...</source>
        <translation>Odczytaj kod...</translation>
    </message>
    <message>
        <source>and type here</source>
        <translation>i wpisz go tutaj</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuluj</translation>
    </message>
</context>
<context>
    <name>ToolBar</name>
    <message>
        <source>Delete toolbar</source>
        <translation>Usuń pasek narzędziowy</translation>
    </message>
    <message>
        <source>Add new button</source>
        <translation>Dodaj nowy przycisk</translation>
    </message>
    <message>
        <source>Remove toolbar?</source>
        <translation>Usunąć pasek narzędziowy?</translation>
    </message>
    <message>
        <source>No items to add found</source>
        <translation>Nie znaleziono elementów do dodania</translation>
    </message>
    <message>
        <source>Show text label</source>
        <translation>Etykieta tekstowa</translation>
    </message>
    <message>
        <source>Delete button</source>
        <translation>Usuń przycisk</translation>
    </message>
    <message>
        <source>Create new toolbar</source>
        <translation>Utwórz nowy pasek narzędziowy</translation>
    </message>
    <message>
        <source>Block toolbars</source>
        <translation>Blokuj paski narzędziowe</translation>
    </message>
</context>
<context>
    <name>Updates</name>
    <message>
        <source>The newest Kadu version is %1</source>
        <translation>Najnowszą wersją Kadu jest %1</translation>
    </message>
</context>
<context>
    <name>UserBox</name>
    <message>
        <source>Hide descriptions</source>
        <translation>Ukryj opisy</translation>
    </message>
    <message>
        <source>Show descriptions</source>
        <translation>Pokaż opis</translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>Statusy</translation>
    </message>
    <message>
        <source>Nicks, case insensitive</source>
        <translation>Nazwa, bez rozróżniania wielkości liter</translation>
    </message>
    <message>
        <source>Nicks</source>
        <translation>Pseudonimy</translation>
    </message>
    <message>
        <source>User management</source>
        <translation>Zarządzanie kontaktami</translation>
    </message>
</context>
<context>
    <name>UserInfo</name>
    <message>
        <source>User info on %1</source>
        <translation>Informacje o %1</translation>
    </message>
    <message>
        <source>Uin</source>
        <translation>Numer GG</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Pseudonim</translation>
    </message>
    <message>
        <source>AltNick</source>
        <translation>Wyświetl</translation>
    </message>
    <message>
        <source>First name</source>
        <translation>Imię</translation>
    </message>
    <message>
        <source>Surname</source>
        <translation>Nazwisko</translation>
    </message>
    <message>
        <source>Mobile</source>
        <translation>Telefon</translation>
    </message>
    <message>
        <source>Address IP and Port</source>
        <translation>Adres IP i port</translation>
    </message>
    <message>
        <source>Protocol version</source>
        <translation>Wersja protokołu</translation>
    </message>
    <message>
        <source>DNS name</source>
        <translation>Nazwa DNS</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>(Unknown)</source>
        <translation>(Nieznany)</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Block user</source>
        <translation>Blokuj kontakt</translation>
    </message>
    <message>
        <source>Offline to user</source>
        <translation>Niedostępny dla kontaktu</translation>
    </message>
    <message>
        <source>Notify about status changes</source>
        <translation>Powiadom o zmianie statusu</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Inne</translation>
    </message>
    <message>
        <source>User known as %1 with that UIN is already in userlist.</source>
        <translation>Kontakt o tym identyfikatorze już istnieje pod pseudonimem %1.</translation>
    </message>
    <message>
        <source>Add user</source>
        <translation>Dodaj kontakt</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Uaktualnij</translation>
    </message>
    <message>
        <source>Altnick field cannot be empty.</source>
        <translation>Pole Wyświetl nie może być puste.</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <source>This dialog box allows you to view and edit information about the selected contact.</source>
        <translation>To okno dialogowe pozwala edytować informacje o wybranym kontakcie.</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>Grupy</translation>
    </message>
    <message>
        <source>Add new group</source>
        <translation>Dodaj nową grupę</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is prohibited</source>
        <translation>&apos;%1&apos; jest zabroniony</translation>
    </message>
    <message>
        <source>This group already exists!</source>
        <translation>Taka grupa już istnieje!</translation>
    </message>
    <message>
        <source>Numbers are prohibited</source>
        <translation>Numery są zakazane</translation>
    </message>
    <message>
        <source>Change icon</source>
        <translation>Zmień ikonę</translation>
    </message>
    <message>
        <source>Delete icon</source>
        <translation>Usuń ikonę</translation>
    </message>
    <message>
        <source>Choose an icon</source>
        <translation>Wybierz ikonę</translation>
    </message>
    <message>
        <source>Icons (*.png *.xpm *.jpg)</source>
        <translation>Ikony (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <source>Icon:</source>
        <translation>Ikona:</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Dostępny</translation>
    </message>
    <message>
        <source>Online (d.)</source>
        <translation>Dostępny z opisem</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Zajęty</translation>
    </message>
    <message>
        <source>Busy (d.)</source>
        <translation>Zajęty z opisem</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Ukryty</translation>
    </message>
    <message>
        <source>Invisible (d.)</source>
        <translation>Ukryty z opisem</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Niedostępny</translation>
    </message>
    <message>
        <source>Offline (d.)</source>
        <translation>Niedostępny z opisem</translation>
    </message>
</context>
<context>
    <name>UserStatus</name>
    <message>
        <source>Online</source>
        <translation>Dostępny</translation>
    </message>
    <message>
        <source>Online (d.)</source>
        <translation>Dostępny z opisem</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Zajęty</translation>
    </message>
    <message>
        <source>Busy (d.)</source>
        <translation>Zajęty z opisem</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Ukryty</translation>
    </message>
    <message>
        <source>Invisible (d.)</source>
        <translation>Ukryty z opisem</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Niedostępny</translation>
    </message>
    <message>
        <source>Offline (d.)</source>
        <translation>Niedostępny z opisem</translation>
    </message>
    <message>
        <source>Blocking</source>
        <translation>Blokuje</translation>
    </message>
</context>
<context>
    <name>UserlistImportExport</name>
    <message>
        <source>Import / export userlist</source>
        <translation>Import / eksport listy kontaktów</translation>
    </message>
    <message>
        <source>This dialog box allows you to import and export your buddy list to a server or a file.</source>
        <translation>To okno dialogowe daje możliwość importu i eksportu listy kontaktów z i na serwer Gadu-Gadu oraz z i do pliku.</translation>
    </message>
    <message>
        <source>Import userlist</source>
        <translation>Import listy kontaktów</translation>
    </message>
    <message>
        <source>UIN</source>
        <translation>Numer GG</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Pseudonim</translation>
    </message>
    <message>
        <source>Disp. nick</source>
        <translation>Wyświetl</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Imię</translation>
    </message>
    <message>
        <source>Surname</source>
        <translation>Nazwisko</translation>
    </message>
    <message>
        <source>Mobile no.</source>
        <translation>Nr telefonu</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Grupa</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>&amp;Fetch userlist</source>
        <translation>&amp;Pobierz listę</translation>
    </message>
    <message>
        <source>&amp;Import from file</source>
        <translation>&amp;Import z pliku</translation>
    </message>
    <message>
        <source>&amp;Save results</source>
        <translation>&amp;Zapisz wyniki</translation>
    </message>
    <message>
        <source>&amp;Merge results</source>
        <translation>&amp;Dołącz wyniki</translation>
    </message>
    <message>
        <source>Export userlist</source>
        <translation>Eksport listy kontaktów</translation>
    </message>
    <message>
        <source>%1 entries will be exported</source>
        <translation>Wyeksportuję %1 wpisów</translation>
    </message>
    <message>
        <source>Se&amp;nd userlist</source>
        <translation>&amp;Wyślij listę</translation>
    </message>
    <message>
        <source>&amp;Delete userlist</source>
        <translation>&amp;Skasuj listę</translation>
    </message>
    <message>
        <source>&amp;Export to file</source>
        <translation>Wy&amp;eksportuj do pliku</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <source>The application encountered an internal error
The import userlist from file was unsuccessful</source>
        <translation>Import listy kontaktów z pliku został zakończony
niepowodzeniem z powodu wewnętrznego błędu</translation>
    </message>
    <message>
        <source>Your userlist has been successfully exported to file</source>
        <translation>Lista kontaktów została wyeksportowana do pliku</translation>
    </message>
    <message>
        <source>The application encountered an internal error
The export userlist to file was unsuccessful</source>
        <translation>Eksport listy kontaktów do pliku
został zakończony niepowodzeniem</translation>
    </message>
    <message>
        <source>Your userlist has been successfully exported to server</source>
        <translation>Lista kontaktów została wyeksportowana na serwer</translation>
    </message>
    <message>
        <source>The application encountered an internal error
The export was unsuccessful</source>
        <translation>Eksport listy kontaktów na serwer
został zakończony niepowodzeniem</translation>
    </message>
    <message>
        <source>Your userlist has been successfully deleted on server</source>
        <translation>Lista kontaktów została usunięta z serwera</translation>
    </message>
    <message>
        <source>The application encountered an internal error
The delete userlist on server was unsuccessful</source>
        <translation>Usunięcie listy kontaktów z serwera
zostało zakończone niepowodzeniem</translation>
    </message>
    <message>
        <source>Cannot import user list from server in offline mode</source>
        <translation>Nie można pobrać listy kontaktów z serwera bez połączenia z nim</translation>
    </message>
    <message>
        <source>This operation will delete your current user list. Are you sure you want this?</source>
        <translation>Ta operacja usunie twoją bieżącą listę kontaktów.
Jesteś pewny że tego chcesz?</translation>
    </message>
    <message>
        <source>Cannot export user list to server in offline mode</source>
        <translation>Nie można wysłać listy kontaktów na serwer bez połączenia z nim</translation>
    </message>
    <message>
        <source>Cannot clear user list on server in offline mode</source>
        <translation>Nie można usunąć listy kontaktów z serwera bez połączenia z nim</translation>
    </message>
    <message>
        <source>File exists. Are you sure you want to overwrite it?</source>
        <translation>Plik już istnieje. Czy na pewno go nadpisać?</translation>
    </message>
</context>
</TS>
